@@ -21,17 +21,25 @@ sub calculate {
 
 	while (--$l >= 0) {
 		$p->setx($p->getx + @Bin[$l]*@Pointxyz[$l]);
-	}
-
-	while (--$l >= 0) {
 		$p->sety($p->gety + @Bin[$l]*@Pointxyz[$l]);
-	}
-
-	while (--$l >= 0) {
 		$p->setz($p->getz + @Bin[$l]*@Pointxyz[$l]);
 	}
 
 	return $p;
 }
 
+### this works somehwat for non-sorted polygons in 3D space
+sub calculate_for_z_order {
+	my ($self, @Bin, @Pointxyz) = @_;
+
+	my $z = 0;
+	my $l = length(@Pointxyz); 
+
+	while (--$l >= 0) {
+		$z += @Bin[$l]*@Pointzyz[$l];
+	}
+
+	return $z;
+}
+
 1;
